Documentation
¶
Index ¶
Constants ¶
const ( AlignLeft = "left" AlignRight = "right" AlignCenter = "center" MarkupPango = "pango" MarkupNone = "none" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Body ¶
type Body struct {
Instance string `json:"instance,omitempty"`
Border string `json:"border,omitempty"`
Markup string `json:"markup,omitempty"`
Background string `json:"background,omitempty"`
FullText string `json:"full_text"`
ShortText string `json:"short_text,omitempty"`
Name string `json:"name"`
Align string `json:"align,omitempty"`
Color string `json:"color,omitempty"`
BorderTop int `json:"border_top,omitempty"`
BorderLeft int `json:"border_left,omitempty"`
BorderBottom int `json:"border_bottom,omitempty"`
MinWidth int `json:"min_width,omitempty"`
SeparatorBlockWidth int `json:"separator_block_width,omitempty"`
BorderRight int `json:"border_right,omitempty"`
Urgent bool `json:"urgent,omitempty"`
Separator bool `json:"separator,omitempty"`
}
Body represents a single element of the infinite swaybar array, where each element represents a block to be rendered by swaybar. (see: man 7 swaybar-protocol)
type ClickEvent ¶
type ClickEvent struct {
Name string `json:"name"`
Instance string `json:"instance"`
X int `json:"x"`
Y int `json:"y"`
Button int `json:"button"`
Event int `json:"event"`
RelativeX int `json:"relative_x"`
RelativeY int `json:"relative_y"`
Width int `json:"width"`
Height int `json:"height"`
}
ClickEvent represents an event that swaybar writes to the standard input when the user clicks on a block.
type Header ¶
type Header struct {
Version int `json:"version"`
ClickEvents bool `json:"click_events,omitempty"`
ContSignal int `json:"cont_signal,omitempty"`
StopSignal int `json:"stop_signal,omitempty"`
}
Header represents the swaybar header as defined in the swaybar json protocol. (see: man 7 swaybar-protocol)
Click to show internal directories.
Click to hide internal directories.